/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { Messages, Global, Mode } from '@salesforce/core';
import chalk from 'chalk';
import { SfCommand } from '@salesforce/sf-plugins-core';
Messages.importMessagesDirectoryFromMetaUrl(import.meta.url);
const messages = Messages.loadMessages('@salesforce/plugin-auth', 'messages');
function dimMessage(message) {
    return chalk.dim(message);
}
export class AuthBaseCommand extends SfCommand {
    constructor(argv, config) {
        super(argv, config);
    }
    async askForHiddenResponse(messageKey, disableMasking = false) {
        const msg = dimMessage(messages.getMessage(messageKey));
        const hidden = await this.prompt({
            message: msg,
            type: 'input',
            name: 'response',
            transformer: (input) => (disableMasking ? input : '*'.repeat(input.length)),
        });
        return hidden.response;
    }
    async shouldExitCommand(noPrompt, message) {
        if (Boolean(noPrompt) || Global.getEnvironmentMode() !== Mode.DEMO) {
            return false;
        }
        else {
            const msg = dimMessage(message ?? messages.getMessage('warnAuth', [this.config.bin]));
            const answer = await this.confirm(msg);
            return !answer;
        }
    }
    async askForClientSecret(disableMasking = false) {
        return this.askForHiddenResponse('clientSecretStdin', disableMasking);
    }
    async askForAccessToken(disableMasking = false) {
        return this.askForHiddenResponse('accessTokenStdin', disableMasking);
    }
}
//# sourceMappingURL=authBaseCommand.js.map