/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { Logger, SfdcUrl, SfProject, Messages, SfError } from '@salesforce/core';
import { getString, isObject } from '@salesforce/ts-types';
Messages.importMessagesDirectoryFromMetaUrl(import.meta.url);
const messages = Messages.loadMessages('@salesforce/plugin-auth', 'messages');
export class Common {
    static async resolveLoginUrl(instanceUrl) {
        const logger = await Logger.child('Common', { tag: 'resolveLoginUrl' });
        if (instanceUrl) {
            throwIfLightning(instanceUrl);
            return instanceUrl;
        }
        let loginUrl;
        try {
            const project = await SfProject.resolve();
            const projectJson = await project.resolveProjectConfig();
            loginUrl = getString(projectJson, 'sfdcLoginUrl', SfdcUrl.PRODUCTION);
        }
        catch (err) {
            const message = (isObject(err) ? Reflect.get(err, 'message') ?? err : err);
            logger.debug(`error occurred while trying to determine loginUrl: ${message}`);
            loginUrl = SfdcUrl.PRODUCTION;
        }
        throwIfLightning(loginUrl);
        logger.debug(`loginUrl: ${loginUrl}`);
        return loginUrl;
    }
}
const throwIfLightning = (urlString) => {
    if (urlString?.match(/\.lightning\..*force\.com/)) {
        throw new SfError(messages.getMessage('lightningInstanceUrl'), 'LightningDomain', [
            messages.getMessage('flags.instance-url.description'),
        ]);
    }
};
//# sourceMappingURL=common.js.map