/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { Messages } from '@salesforce/core';
import { BulkDeleteRequestCache } from '../../../bulkDataRequestCache.js';
import { BulkOperationCommand } from '../../../bulkOperationCommand.js';
import { validateSobjectType } from '../../../bulkUtils.js';
Messages.importMessagesDirectoryFromMetaUrl(import.meta.url);
const messages = Messages.loadMessages('@salesforce/plugin-data', 'bulkv2.delete');
export default class Delete extends BulkOperationCommand {
    static examples = messages.getMessages('examples');
    static summary = messages.getMessage('summary');
    static description = messages.getMessage('description');
    async run() {
        const { flags } = await this.parse(Delete);
        const conn = flags['target-org'].getConnection(flags['api-version']);
        await validateSobjectType(flags.sobject, conn);
        return this.runBulkOperation(flags.sobject, flags.file, conn, flags.async ? 0 : flags.wait?.minutes, flags.verbose, 'delete');
    }
    // eslint-disable-next-line class-methods-use-this
    async getCache() {
        return BulkDeleteRequestCache.create();
    }
}
//# sourceMappingURL=bulk.js.map