/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import chalk from 'chalk';
const styledProperties = new Map([
    [
        'status',
        new Map([
            ['Active', chalk.green],
            ['else', chalk.red],
        ]),
    ],
    [
        'connectedStatus',
        new Map([
            ['Connected', chalk.green],
            ['Active', chalk.green],
            ['else', chalk.red],
        ]),
    ],
]);
export const getStyledValue = (key, value) => {
    if (!value)
        return value;
    const prop = styledProperties.get(key);
    if (!prop)
        return value;
    // I'm not sure how to type the inner Map so that it knows else is definitely there
    const chalkMethod = prop.get(value) ?? prop.get('else');
    return chalkMethod(value);
};
export const getStyledObject = (objectToStyle) => Object.fromEntries(Object.entries(objectToStyle).map(([key, value]) => [
    key,
    typeof value === 'string' ? getStyledValue(key, value) : value,
]));
//# sourceMappingURL=orgHighlighter.js.map