/*
 * Copyright (c) 2021, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { fileURLToPath } from 'node:url';
import { dirname } from 'node:path';
import { SfCommand, Flags } from '@salesforce/sf-plugins-core';
import { Messages } from '@salesforce/core';
import { apiNamePrompt, descriptionPrompt, directoryPrompt, pluralPrompt } from '../../../shared/prompts/prompts.js';
import { writeObjectFile } from '../../../shared/fs.js';
import { labelValidation } from '../../../shared/flags.js';
Messages.importMessagesDirectory(dirname(fileURLToPath(import.meta.url)));
const messages = Messages.loadMessages('@salesforce/plugin-sobject', 'generate.event');
export default class PlatformEventGenerate extends SfCommand {
    static summary = messages.getMessage('summary');
    static description = messages.getMessage('description');
    static examples = messages.getMessages('examples');
    static requiresProject = true;
    static enableJsonFlag = false;
    static aliases = ['generate:metadata:platformevent'];
    static deprecateAliases = true;
    static flags = {
        label: Flags.string({
            char: 'l',
            summary: messages.getMessage('flags.label.summary'),
            required: true,
            parse: async (label) => labelValidation(label),
        }),
    };
    async run() {
        const { flags } = await this.parse(PlatformEventGenerate);
        const responses = await this.prompt([
            await directoryPrompt(this.project.getPackageDirectories()),
            pluralPrompt(flags.label),
            apiNamePrompt(flags.label, 'PlatformEvent'),
            descriptionPrompt,
            {
                type: 'list',
                message: messages.getMessage('prompts.publishBehavior'),
                name: 'publishBehavior',
                choices: ['PublishImmediately', 'PublishAfterCommit'],
            },
        ]);
        const { directory, ...platformEvent } = responses;
        const objectToWrite = {
            ...platformEvent,
            deploymentStatus: 'Deployed',
            eventType: 'HighVolume',
            label: flags.label,
        };
        this.styledJSON(objectToWrite);
        const writePath = await writeObjectFile(directory, objectToWrite);
        return { object: objectToWrite, path: writePath };
    }
}
//# sourceMappingURL=platformevent.js.map