/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { Messages } from '@salesforce/core';
import { arrayWithDeprecation, Flags, loglevel, orgApiVersionFlagWithDeprecations } from '@salesforce/sf-plugins-core';
import { ensureArray } from '@salesforce/kit';
import { UserPermSetLicenseAssignBaseCommand } from '../../../../baseCommands/user/permsetlicense/assign.js';
Messages.importMessagesDirectoryFromMetaUrl(import.meta.url);
const messages = Messages.loadMessages('@salesforce/plugin-user', 'permsetlicense.assign');
export class ForceUserPermSetLicenseAssignCommand extends UserPermSetLicenseAssignBaseCommand {
    static hidden = true;
    static summary = messages.getMessage('summary');
    static description = messages.getMessage('description');
    static examples = messages.getMessages('examples');
    static state = 'deprecated';
    static deprecationOptions = {
        to: 'org assign permsetlicense',
    };
    static flags = {
        name: Flags.string({
            char: 'n',
            summary: messages.getMessage('flags.name.summary'),
            required: true,
            aliases: ['perm-set-license', 'psl'],
        }),
        'on-behalf-of': arrayWithDeprecation({
            char: 'b',
            summary: messages.getMessage('flags.onBehalfOf.summary'),
            aliases: ['onbehalfof'],
            deprecateAliases: true,
        }),
        'target-org': Flags.requiredOrg({
            char: 'u',
            summary: messages.getMessage('flags.target-org.summary'),
            aliases: ['targetusername'],
            deprecateAliases: true,
            required: true,
        }),
        'api-version': orgApiVersionFlagWithDeprecations,
        loglevel,
    };
    async run() {
        const { flags } = await this.parse(ForceUserPermSetLicenseAssignCommand);
        return this.assign({
            conn: flags['target-org'].getConnection(flags['api-version']),
            pslName: flags.name,
            usernamesOrAliases: ensureArray(flags['on-behalf-of'] ?? flags['target-org'].getUsername()),
        });
    }
}
//# sourceMappingURL=assign.js.map