/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { Messages } from '@salesforce/core';
import { arrayWithDeprecation, Flags } from '@salesforce/sf-plugins-core';
import { ensureArray } from '@salesforce/kit';
import { UserPermSetLicenseAssignBaseCommand } from '../../../baseCommands/user/permsetlicense/assign.js';
Messages.importMessagesDirectoryFromMetaUrl(import.meta.url);
const messages = Messages.loadMessages('@salesforce/plugin-user', 'permsetlicense.assign');
export class AssignPermSetLicenseCommand extends UserPermSetLicenseAssignBaseCommand {
    static summary = messages.getMessage('summary');
    static description = messages.getMessage('description');
    static examples = messages.getMessages('examples');
    static flags = {
        name: Flags.string({
            char: 'n',
            summary: messages.getMessage('flags.name.summary'),
            required: true,
            aliases: ['perm-set-license', 'psl'],
        }),
        'on-behalf-of': arrayWithDeprecation({
            char: 'b',
            summary: messages.getMessage('flags.onBehalfOf.summary'),
            aliases: ['onbehalfof'],
            deprecateAliases: true,
        }),
        'target-org': Flags.requiredOrg({ summary: messages.getMessage('flags.target-org.summary'), required: true }),
        'api-version': Flags.orgApiVersion(),
    };
    async run() {
        const { flags } = await this.parse(AssignPermSetLicenseCommand);
        return this.assign({
            conn: flags['target-org'].getConnection(flags['api-version']),
            pslName: flags.name,
            usernamesOrAliases: ensureArray(flags['on-behalf-of'] ?? flags['target-org'].getUsername()),
        });
    }
}
//# sourceMappingURL=permsetlicense.js.map